@@ -11,6 +11,7 @@ use Moose                     ();
 use MooseX::StrictConstructor ();
 use mro                       ();
 use namespace::autoclean      ();
+use Moose::Util 'throw_exception';
 use Module::Load 'load';
 use MooseX::Extended::Core qw(
   field
@@ -25,7 +26,7 @@ use Import::Into;
 
 no warnings _disabled_warnings();
 
-our $VERSION = '0.07';
+our $VERSION = '0.10';
 
 my ( $import, undef, $init_meta ) = Moose::Exporter->setup_import_methods(
     with_meta => [ 'field', 'param' ],
@@ -75,7 +76,13 @@ Filename: $filename
 Line:     $line
 Details:  $error
 END
-        die;
+        throw_exception(
+            'InvalidImportList',
+            class_name           => $package,
+            moosex_extended_type => __PACKAGE__,
+            line_number          => $line,
+            messsage             => $error,
+        );
     };
 
     # remap the arrays to hashes for easy lookup
@@ -119,7 +126,7 @@ sub init_meta ( $class, %params ) {
 
     # see perldoc -v '$^P'
     if ($^P) {
-        say STDERR "We are running under the debugger. $for_class is not immutable";
+        say STDERR "We are running under the debugger or using code that uses debugger code (e.g., Devel::Cover). $for_class is not immutable";
     }
     else {
         unless ( $config->{excludes}{immutable} ) {
@@ -178,7 +185,7 @@ MooseX::Extended - Extend Moose with safe defaults and useful features
 
 =head1 VERSION
 
-version 0.07
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -214,14 +221,14 @@ version 0.07
 =head1 DESCRIPTION
 
 This module is B<BETA> code. It's feature-complete for release and has no
-known bugs, but more testing is warranted.
+known bugs.
 
 This class attempts to create a safer version of Moose that defaults to
 read-only attributes and is easier to read and write.
 
-It tries to bring some of the lessons learned from L<the Corinna project|https://github.com/Ovid/Cor>,
-while acknowledging that you can't always get what you want (such as
-true encapsulation and true methods).
+It tries to bring some of the lessons learned from L<the Corinna
+project|https://github.com/Ovid/Cor>, while acknowledging that you can't
+always get what you want (such as true encapsulation and true methods).
 
 This:
 
@@ -277,7 +284,7 @@ can even safely inline multiple packages in the same file:
         $self->set_y($x);
     }
 
-# MooseX::Extended will causet this to return true, even if we try to return
+# MooseX::Extended will cause this to return true, even if we try to return
 # false
 0;
 
@@ -291,7 +298,7 @@ You may pass an import list to L<MooseX::Extended>.
 
 =head2 C<types>
 
-ALlows you to import any types provided by L<MooseX::Extended::Types>.
+Allows you to import any types provided by L<MooseX::Extended::Types>.
 
 This:
 
